SphinxFolders
=============

Sphinx directive to list the content of a folder

Sample usage::


    .. folder:: _static/demo_folder
        :class: folder
        :desc_ext: .desc
        :glob: *.pdf
